@@ -19,6 +19,7 @@
 require 'pp'
 require 'socket'
 require 'chef/config'
+require 'chef/config_fetcher'
 require 'chef/exceptions'
 require 'chef/log'
 require 'chef/platform'
@@ -118,11 +119,13 @@ class Chef::Application
       configure_stdout_logger
     end
     Chef::Log.level = resolve_log_level
+  rescue StandardError => error
+    Chef::Log.fatal("Failed to open or create log file at #{Chef::Config[:log_location]}: #{error.class} (#{error.message})")
+    Chef::Application.fatal!("Aborting due to invalid 'log_location' configuration", 2)
   end
 
   def configure_stdout_logger
     stdout_logger = MonoLogger.new(STDOUT)
-    STDOUT.sync = true
     stdout_logger.formatter = Chef::Log.logger.formatter
     Chef::Log.loggers <<  stdout_logger
   end
@@ -196,12 +199,18 @@ class Chef::Application
   end
 
   # Initializes Chef::Client instance and runs it
-  def run_chef_client
+  def run_chef_client(specific_recipes = [])
     Chef::Application.setup_server_connectivity
 
+    override_runlist = config[:override_runlist]
+    if specific_recipes.size > 0
+      override_runlist ||= []
+    end
     @chef_client = Chef::Client.new(
       @chef_client_json,
-      :override_runlist => config[:override_runlist]
+      :override_runlist => config[:override_runlist],
+      :specific_recipes => specific_recipes,
+      :runlist => config[:runlist]
     )
     @chef_client_json = nil
 
