@@ -19,6 +19,8 @@ require 'chef/knife'
 require 'chef/application'
 require 'mixlib/log'
 require 'ohai/config'
+require 'chef/monkey_patches/net_http.rb'
+require 'chef/monkey_patches/uri.rb'
 
 class Chef::Application::Knife < Chef::Application
 
