@@ -8,6 +8,7 @@ require 'chef/cookbook_version'
 require 'chef/cookbook/syntax_check'
 require 'chef/cookbook/file_system_file_vendor'
 require 'chef/sandbox'
+require 'thread'
 
 class Chef
   class CookbookUploader
@@ -16,10 +17,10 @@ class Chef
       @work_queue ||= Queue.new
     end
 
-    def self.setup_worker_threads
+    def self.setup_worker_threads(concurrency=10)
       @worker_threads ||= begin
         work_queue
-        (1...10).map do
+        (1..concurrency).map do
           Thread.new do
             loop do
               work_queue.pop.call
@@ -33,6 +34,7 @@ class Chef
     attr_reader :path
     attr_reader :opts
     attr_reader :rest
+    attr_reader :concurrency
 
     # Creates a new CookbookUploader.
     # ===Arguments:
@@ -49,10 +51,13 @@ class Chef
     # * :rest   A Chef::REST object that you have configured the way you like it.
     #           If you don't provide this, one will be created using the values
     #           in Chef::Config.
+    # * :concurrency   An integer that decided how many threads will be used to
+    #           perform concurrent uploads
     def initialize(cookbooks, path, opts={})
       @path, @opts = path, opts
       @cookbooks = Array(cookbooks)
       @rest = opts[:rest] || Chef::REST.new(Chef::Config[:chef_server_url])
+      @concurrency = opts[:concurrency] || 10
     end
 
     def upload_cookbooks
@@ -72,7 +77,7 @@ class Chef
 
       Chef::Log.info("Uploading files")
 
-      self.class.setup_worker_threads
+      self.class.setup_worker_threads(concurrency)
 
       checksums_to_upload = Set.new
 
@@ -137,7 +142,7 @@ class Chef
         timestamp = Time.now.utc.iso8601
         file_contents = File.open(file, "rb") {|f| f.read}
         # TODO - 5/28/2010, cw: make signing and sending the request streaming
-        headers = { 'content-type' => 'application/x-binary', 'content-md5' => checksum64, :accept => 'application/json' }
+        headers = { 'content-type' => 'application/x-binary', 'content-md5' => checksum64, "accept" => 'application/json' }
         if rest.signing_key
           sign_obj = Mixlib::Authentication::SignedHeaderAuth.signing_object(
                                                                              :http_method => :put,
@@ -150,10 +155,12 @@ class Chef
         end
 
         begin
-          RestClient::Resource.new(url, :headers=>headers, :timeout=>1800, :open_timeout=>1800).put(file_contents)
+          Chef::HTTP::Simple.new(url, :headers=>headers).put(url, file_contents)
           checksums_to_upload.delete(checksum)
-        rescue RestClient::Exception => e
-          Chef::Knife.ui.error("Failed to upload #@cookbook : #{e.message}\n#{e.response.body}")
+        rescue Net::HTTPServerException, Net::HTTPFatalError, Errno::ECONNREFUSED, Timeout::Error, Errno::ETIMEDOUT, SocketError => e
+          error_message = "Failed to upload #{file} (#{checksum}) to #{url} : #{e.message}"
+          error_message << "\n#{e.response.body}" if e.respond_to?(:response)
+          Chef::Knife.ui.error(error_message)
           raise
         end
       end
