@@ -239,7 +239,13 @@ class Chef
     end
 
     def self.working_directory
-      ENV['PWD'] || Dir.pwd
+      a = if Chef::Platform.windows?
+            ENV['CD']
+          else
+            ENV['PWD']
+          end || Dir.pwd
+
+      a
     end
 
     def self.reset_config_path!
@@ -415,6 +421,7 @@ class Chef
 
       # Don't try to load a knife.rb if it wasn't specified.
       if config[:config_file]
+        Chef::Config.config_file = config[:config_file]
         fetcher = Chef::ConfigFetcher.new(config[:config_file], Chef::Config.config_file_jail)
         if fetcher.config_missing?
           ui.error("Specified config file #{config[:config_file]} does not exist#{Chef::Config.config_file_jail ? " or is not under config file jail #{Chef::Config.config_file_jail}" : ""}!")
