@@ -91,7 +91,7 @@ class Chef
 
       option :bootstrap_no_proxy,
         :long => "--bootstrap-no-proxy [NO_PROXY_URL|NO_PROXY_IP]",
-        :description => "Do not proxy locations for the node being bootstrapped",
+        :description => "Do not proxy locations for the node being bootstrapped; this option is used internally by Opscode",
         :proc => Proc.new { |np| Chef::Config[:knife][:bootstrap_no_proxy] = np }
 
       option :distro,
@@ -201,7 +201,7 @@ class Chef
 
         $stdout.sync = true
 
-        ui.info("Bootstrapping Chef on #{ui.color(@node_name, :bold)}")
+        ui.info("Connecting to #{ui.color(@node_name, :bold)}")
 
         begin
           knife_ssh.run
