@@ -84,17 +84,17 @@ class Chef
         when nil
           dest
         when Hash
-          source.each do |src_key, src_value|
-            if dest.kind_of?(Hash)
+          if dest.kind_of?(Hash)
+            source.each do |src_key, src_value|
               if dest[src_key]
                 dest[src_key] = deep_merge!(src_value, dest[src_key])
               else # dest[src_key] doesn't exist so we take whatever source has
                 raise_if_knockout_used!(src_value)
                 dest[src_key] = src_value
               end
-            else # dest isn't a hash, so we overwrite it completely
-              dest = source
             end
+          else # dest isn't a hash, so we overwrite it completely
+            dest = source
           end
         when Array
           if dest.kind_of?(Array)
@@ -111,7 +111,13 @@ class Chef
       end # deep_merge!
 
       def hash_only_merge(merge_onto, merge_with)
-        hash_only_merge!(merge_onto.dup, merge_with.dup)
+        hash_only_merge!(safe_dup(merge_onto), safe_dup(merge_with))
+      end
+
+      def safe_dup(thing)
+        thing.dup
+      rescue TypeError
+        thing
       end
 
       # Deep merge without Array merge.
@@ -122,7 +128,11 @@ class Chef
         # If there are two Hashes, recursively merge.
         if merge_onto.kind_of?(Hash) && merge_with.kind_of?(Hash)
           merge_with.each do |key, merge_with_value|
-            merge_onto[key] = hash_only_merge!(merge_onto[key], merge_with_value)
+            merge_onto[key] = if merge_onto.has_key?(key)
+                                hash_only_merge(merge_onto[key], merge_with_value)
+                              else
+                                merge_with_value
+                              end
           end
           merge_onto
 
@@ -158,11 +168,9 @@ class Chef
       end
 
       def deep_merge(source, dest)
-        deep_merge!(source.dup, dest.dup)
+        deep_merge!(safe_dup(source), safe_dup(dest))
       end
 
     end
   end
 end
-
-
