@@ -75,7 +75,8 @@ class Chef
         @current_resource ||= Chef::Resource::File.new(@new_resource.name)
         @current_resource.path(@new_resource.path)
         if ::File.exists?(@current_resource.path) && ::File.file?(::File.realpath(@current_resource.path))
-          if @action != :create_if_missing && @current_resource.respond_to?(:checksum)
+          if managing_content?
+            Chef::Log.debug("#{@new_resource} checksumming file at #{@new_resource.path}.")
             @current_resource.checksum(checksum(@current_resource.path))
           end
           load_resource_attributes_from_file(@current_resource)
@@ -159,6 +160,15 @@ class Chef
 
       private
 
+      # What to check in this resource to see if we're going to be actively managing
+      # content (for things like doing checksums in load_current_resource).  Expected to
+      # be overridden in subclasses.
+      def managing_content?
+        return true if @new_resource.checksum
+        return true if !@new_resource.content.nil? && @action != :create_if_missing
+        false
+      end
+
       # Handles resource requirements for action :create when some fs entry
       # already exists at the destination path. For actions other than create,
       # we don't care what kind of thing is at the destination path because:
@@ -240,8 +250,8 @@ class Chef
 
       def content
         @content ||= begin
-           load_current_resource if @current_resource.nil?
-           @content_class.new(@new_resource, @current_resource, @run_context)
+          load_current_resource if @current_resource.nil?
+          @content_class.new(@new_resource, @current_resource, @run_context)
         end
       end
 
@@ -330,7 +340,9 @@ class Chef
         do_backup unless file_created?
         deployment_strategy.deploy(tempfile.path, ::File.realpath(@new_resource.path))
         Chef::Log.info("#{@new_resource} updated file contents #{@new_resource.path}")
-        @new_resource.checksum(checksum(@new_resource.path)) # for reporting
+        if managing_content?
+          @new_resource.checksum(checksum(@new_resource.path)) # for reporting
+        end
       end
 
       def do_contents_changes
@@ -340,17 +352,29 @@ class Chef
         if tempfile.path.nil? || !::File.exists?(tempfile.path)
           raise "chef-client is confused, trying to deploy a file that has no path or does not exist..."
         end
+
         # the file? on the next line suppresses the case in why-run when we have a not-file here that would have otherwise been removed
         if ::File.file?(@new_resource.path) && contents_changed?
-          diff.diff(@current_resource.path, tempfile.path)
-          @new_resource.diff( diff.for_reporting ) unless file_created?
-          description = [ "update content in file #{@new_resource.path} from #{short_cksum(@current_resource.checksum)} to #{short_cksum(checksum(tempfile.path))}" ]
-          description << diff.for_output
+          description = [ "update content in file #{@new_resource.path} from \
+#{short_cksum(@current_resource.checksum)} to #{short_cksum(checksum(tempfile.path))}" ]
+
+          # Hide the diff output if the resource is marked as a sensitive resource
+          if @new_resource.sensitive
+            @new_resource.diff("suppressed sensitive resource")
+            description << "suppressed sensitive resource"
+          else
+            diff.diff(@current_resource.path, tempfile.path)
+            @new_resource.diff( diff.for_reporting ) unless file_created?
+            description << diff.for_output
+          end
+
           converge_by(description) do
             update_file_contents
           end
         end
+
         # unlink necessary to clean up in why-run mode
+        tempfile.close
         tempfile.unlink
       end
 
@@ -379,6 +403,7 @@ class Chef
       end
 
       def contents_changed?
+        Chef::Log.debug "calculating checksum of #{tempfile.path} to compare with #{@current_resource.checksum}"
         checksum(tempfile.path) != @current_resource.checksum
       end
 
@@ -407,4 +432,3 @@ class Chef
     end
   end
 end
-
