@@ -39,25 +39,20 @@ class Chef
           end
         end
 
-        def modify_group_members
-            if(@new_resource.append)
-              unless @new_resource.members.empty?
-                @new_resource.members.each do |member|
-                  Chef::Log.debug("#{@new_resource} appending member #{member} to group #{@new_resource.group_name}")
-                  shell_out!("gpasswd -a #{member} #{@new_resource.group_name}")
-                end
-              else
-                Chef::Log.debug("#{@new_resource} not changing group members, the group has no members to add")
-              end
-            else
-              unless @new_resource.members.empty?
-                Chef::Log.debug("#{@new_resource} setting group members to #{@new_resource.members.join(', ')}")
-                shell_out!("gpasswd -M #{@new_resource.members.join(',')} #{@new_resource.group_name}")
-              else
-                Chef::Log.debug("#{@new_resource} setting group members to: none")
-                shell_out!("gpasswd -M \"\" #{@new_resource.group_name}")
-              end
-            end
+        def set_members(members)
+          unless members.empty?
+            shell_out!("gpasswd -M #{members.join(',')} #{@new_resource.group_name}")
+          else
+            shell_out!("gpasswd -M \"\" #{@new_resource.group_name}")
+          end
+        end
+
+        def add_member(member)
+          shell_out!("gpasswd -a #{member} #{@new_resource.group_name}")
+        end
+
+        def remove_member(member)
+          shell_out!("gpasswd -d #{member} #{@new_resource.group_name}")
         end
       end
     end
