@@ -39,6 +39,14 @@ class Chef
         super
       end
 
+      private
+
+      def managing_content?
+        return true if @new_resource.checksum
+        return true if !@new_resource.source.nil? && @action != :create_if_missing
+        false
+      end
+
     end
   end
 end
