@@ -25,11 +25,13 @@ class Chef
     class Service
       class Solaris < Chef::Provider::Service
         include Chef::Mixin::ShellOut
+        attr_reader :maintenance
 
         def initialize(new_resource, run_context=nil)
           super
           @init_command = "/usr/sbin/svcadm"
           @status_command = "/bin/svcs -l"
+          @maintenace     = false
         end
 
 
@@ -44,6 +46,7 @@ class Chef
         end
 
         def enable_service
+          shell_out!("#{default_init_command} clear #{@new_resource.service_name}") if @maintenance
           shell_out!("#{default_init_command} enable -s #{@new_resource.service_name}")
         end
 
@@ -65,13 +68,14 @@ class Chef
         end
 
         def service_status
-          status = popen4("#{@status_command} #{@current_resource.service_name}") do |pid, stdin, stdout, stderr|
-            stdout.each do |line|
-              case line
-              when /state\s+online/
-                @current_resource.enabled(true)
-                @current_resource.running(true)
-              end
+          status = shell_out!("#{@status_command} #{@current_resource.service_name}")
+          status.stdout.each_line do |line|
+            case line
+            when /state\s+online/
+              @current_resource.enabled(true)
+              @current_resource.running(true)
+            when /state\s+maintenance/
+              @maintenance = true
             end
           end
           unless @current_resource.enabled
