@@ -23,6 +23,7 @@ require 'chef/dsl/data_query'
 require 'chef/dsl/platform_introspection'
 require 'chef/dsl/include_recipe'
 require 'chef/dsl/registry_helper'
+require 'chef/dsl/reboot_pending'
 
 require 'chef/mixin/from_file'
 
@@ -38,6 +39,7 @@ class Chef
     include Chef::DSL::IncludeRecipe
     include Chef::DSL::Recipe
     include Chef::DSL::RegistryHelper
+    include Chef::DSL::RebootPending
 
     include Chef::Mixin::FromFile
     include Chef::Mixin::Deprecation
