@@ -68,6 +68,8 @@ require 'chef/resource/smartos_package'
 require 'chef/resource/template'
 require 'chef/resource/timestamped_deploy'
 require 'chef/resource/user'
+require 'chef/resource/whyrun_safe_ruby_block'
+require 'chef/resource/windows_package'
 require 'chef/resource/yum_package'
 require 'chef/resource/lwrp_base'
 require 'chef/resource/bff_package'
