@@ -482,7 +482,7 @@ shared_examples_for "a securable resource without existing target" do
 
       it 'warns when mode tries to set owner bits but owner is not specified' do
         @warn = []
-        Chef::Log.stub!(:warn) { |msg| @warn << msg }
+        Chef::Log.stub(:warn) { |msg| @warn << msg }
 
         resource.mode 0400
         resource.run_action(:create)
@@ -492,7 +492,7 @@ shared_examples_for "a securable resource without existing target" do
 
       it 'warns when mode tries to set group bits but group is not specified' do
         @warn = []
-        Chef::Log.stub!(:warn) { |msg| @warn << msg }
+        Chef::Log.stub(:warn) { |msg| @warn << msg }
 
         resource.mode 0040
         resource.run_action(:create)
