@@ -29,8 +29,8 @@ describe Chef::Mixin::Checksum do
     @checksum_user = Chef::CMCCheck.new
     @cache = Chef::Digester.instance
     @file = CHEF_SPEC_DATA + "/checksum/random.txt"
-    @stat = mock("File::Stat", { :mtime => Time.at(0) })
-    File.stub!(:stat).and_return(@stat)
+    @stat = double("File::Stat", { :mtime => Time.at(0) })
+    File.stub(:stat).and_return(@stat)
   end
 
   it "gets the checksum of a file" do
