@@ -437,7 +437,7 @@ describe Chef::Node::Attribute do
 
     it "should let you set an attribute value when another hash has an intermediate value" do
       @attributes.normal["the_ghost"] = { "exterminate" => "the future" }
-      lambda { @attributes.normal["the_ghost"]["exterminate"]["tomorrow"] = false }.should_not raise_error(NoMethodError)
+      lambda { @attributes.normal["the_ghost"]["eviscerate"]["tomorrow"] = false }.should_not raise_error
     end
 
     it "should set the attribute value" do
@@ -488,6 +488,13 @@ describe Chef::Node::Attribute do
     end
   end
 
+  describe "dup" do
+    it "array can be duped even if some elements can't" do
+      @attributes.default[:foo] = %w[foo bar baz] + Array(1..3) + [nil, true, false, [ "el", 0, nil ] ]
+      @attributes.default[:foo].dup
+    end
+  end
+
   describe "has_key?" do
     it "should return true if an attribute exists" do
       @attributes.has_key?("music").should == true
@@ -597,7 +604,7 @@ describe Chef::Node::Attribute do
     end
 
     it "should not raise an exception if one of the hashes has a nil value on a deep lookup" do
-      lambda { @attributes.place.keys { |k| } }.should_not raise_error(NoMethodError)
+      lambda { @attributes.place.keys { |k| } }.should_not raise_error
     end
   end
 
@@ -981,7 +988,7 @@ describe Chef::Node::Attribute do
 
     if RUBY_VERSION >= "1.8.7"
       it "should not raise a LocalJumpError if no block is given" do
-        lambda { @attributes.select }.should_not raise_error(LocalJumpError)
+        lambda { @attributes.select }.should_not raise_error
       end
     else
       it "should raise a LocalJumpError if no block is given" do
