@@ -19,22 +19,144 @@
 require 'spec_helper'
 
 describe Chef::Provider::Cron do
+  describe "when with special time string" do
+    before do
+      @node = Chef::Node.new
+      @events = Chef::EventDispatch::Dispatcher.new
+      @run_context = Chef::RunContext.new(@node, {}, @events)
+      
+      @new_resource = Chef::Resource::Cron.new("cronhole some stuff", @run_context)
+      @new_resource.user "root"
+      @new_resource.minute "30"
+      @new_resource.command "/bin/true"
+      @new_resource.time :reboot
+      @provider = Chef::Provider::Cron.new(@new_resource, @run_context)
+    end
+    
+    context "with a matching entry in the user's crontab" do
+      before :each do
+        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+0 2 * * * /some/other/command
+
+# Chef Name: cronhole some stuff
+@reboot /bin/true param1 param2
+# Chef Name: something else
+2 * 1 * * /bin/false
+
+# Another comment
+CRONTAB
+      end
+      
+      it "should set cron_exists" do
+        @provider.load_current_resource
+        @provider.cron_exists.should == true
+        @provider.cron_empty.should == false
+      end
+
+      it "should pull the details out of the cron line" do
+        cron = @provider.load_current_resource
+        cron.time.should == :reboot
+        cron.command.should == '/bin/true param1 param2'
+      end
+
+      it "should pull env vars out" do
+        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+0 2 * * * /some/other/command
+
+# Chef Name: cronhole some stuff
+MAILTO=foo@example.com
+SHELL=/bin/foosh
+PATH=/bin:/foo
+HOME=/home/foo
+@reboot /bin/true param1 param2
+# Chef Name: something else
+2 * 1 * * /bin/false
+
+# Another comment
+CRONTAB
+        cron = @provider.load_current_resource
+        cron.mailto.should == 'foo@example.com'
+        cron.shell.should == '/bin/foosh'
+        cron.path.should == '/bin:/foo'
+        cron.home.should == '/home/foo'
+        cron.time.should == :reboot
+        cron.command.should == '/bin/true param1 param2'
+      end
+
+      it "should parse and load generic and standard environment variables from cron entry" do
+        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+# Chef Name: cronhole some stuff
+MAILTO=warn@example.com
+TEST=lol
+FLAG=1
+@reboot /bin/true
+CRONTAB
+        cron = @provider.load_current_resource
+
+        cron.mailto.should == "warn@example.com"
+        cron.environment.should == {"TEST" => "lol", "FLAG" => "1"}
+      end
+
+      it "should not break with variables that match the cron resource internals" do
+        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+# Chef Name: cronhole some stuff
+MINUTE=40
+REBOOT=midnight
+TEST=lol
+ENVIRONMENT=production
+@reboot /bin/true
+CRONTAB
+        cron = @provider.load_current_resource
+
+        cron.time.should == :reboot
+        cron.environment.should == {"MINUTE" => "40", "REBOOT" => "midnight", "TEST" => "lol", "ENVIRONMENT" => "production"}
+      end
+
+      it "should report the match" do
+        Chef::Log.should_receive(:debug).with("Found cron '#{@new_resource.name}'")
+        @provider.load_current_resource
+      end
+      
+      describe "action_create" do
+        before :each do
+          @provider.stub!(:write_crontab)
+          @provider.stub!(:read_crontab).and_return(nil)
+        end
+
+        context "when there is no existing crontab" do
+          before :each do
+            @provider.cron_exists = false
+            @provider.cron_empty = true
+          end
+    
+          it "should create a crontab with the entry" do
+            @provider.should_receive(:write_crontab).with(<<-ENDCRON)
+# Chef Name: cronhole some stuff
+@reboot /bin/true
+            ENDCRON
+            @provider.run_action(:create)
+          end
+        end
+      end
+    end
+  end
+  
   before do
     @node = Chef::Node.new
     @events = Chef::EventDispatch::Dispatcher.new
     @run_context = Chef::RunContext.new(@node, {}, @events)
+    
     @new_resource = Chef::Resource::Cron.new("cronhole some stuff", @run_context)
     @new_resource.user "root"
     @new_resource.minute "30"
     @new_resource.command "/bin/true"
-
     @provider = Chef::Provider::Cron.new(@new_resource, @run_context)
   end
 
   describe "when examining the current system state" do
     context "with no crontab for the user" do
       before :each do
-        @provider.stub!(:read_crontab).and_return(nil)
+        @provider.stub(:read_crontab).and_return(nil)
       end
 
       it "should set cron_empty" do
@@ -51,7 +173,7 @@ describe Chef::Provider::Cron do
 
     context "with no matching entry in the user's crontab" do
       before :each do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: something else
@@ -73,7 +195,7 @@ CRONTAB
       end
 
       it "should not fail if there's an existing cron with a numerical argument" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 # Chef Name: foo[bar] (baz)
 21 */4 * * * some_prog 1234567
 CRONTAB
@@ -85,7 +207,7 @@ CRONTAB
 
     context "with a matching entry in the user's crontab" do
       before :each do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -110,11 +232,12 @@ CRONTAB
         cron.day.should == '*'
         cron.month.should == '1'
         cron.weekday.should == '*'
+        cron.time.should == nil
         cron.command.should == '/bin/true param1 param2'
       end
 
       it "should pull env vars out" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -138,11 +261,12 @@ CRONTAB
         cron.day.should == '*'
         cron.month.should == '1'
         cron.weekday.should == '*'
+        cron.time.should == nil
         cron.command.should == '/bin/true param1 param2'
       end
 
       it "should parse and load generic and standard environment variables from cron entry" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 # Chef Name: cronhole some stuff
 MAILTO=warn@example.com
 TEST=lol
@@ -156,7 +280,7 @@ CRONTAB
       end
 
       it "should not break with variabels that match the cron resource internals" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 # Chef Name: cronhole some stuff
 MINUTE=40
 HOUR=midnight
@@ -179,7 +303,7 @@ CRONTAB
 
     context "with a matching entry in the user's crontab using month names and weekday names (#CHEF-3178)" do
       before :each do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -215,7 +339,7 @@ CRONTAB
 
     context "with a matching entry without a crontab line" do
       it "should set cron_exists and leave current_resource values at defaults" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -227,11 +351,12 @@ CRONTAB
         cron.day.should == '*'
         cron.month.should == '*'
         cron.weekday.should == '*'
+        cron.time.should == nil
         cron.command.should == nil
       end
 
       it "should not pick up a commented out crontab line" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -244,11 +369,12 @@ CRONTAB
         cron.day.should == '*'
         cron.month.should == '*'
         cron.weekday.should == '*'
+        cron.time.should == nil
         cron.command.should == nil
       end
 
       it "should not pick up a later crontab entry" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -265,6 +391,7 @@ CRONTAB
         cron.day.should == '*'
         cron.month.should == '*'
         cron.weekday.should == '*'
+        cron.time.should == nil
         cron.command.should == nil
       end
     end
@@ -286,11 +413,22 @@ CRONTAB
       end
     end
 
+    it "should return true if special time string doesn't match" do
+      @new_resource.send(:time, :reboot)
+      @provider.cron_different?.should eql(true)
+    end
+    
     it "should return true if environment doesn't match" do
       @new_resource.environment "FOO" => "something_else"
       @provider.cron_different?.should eql(true)
     end
 
+    it "should return true if mailto doesn't match" do
+      @current_resource.mailto "foo@bar.com"
+      @new_resource.mailto(nil)
+      @provider.cron_different?.should eql(true)
+    end
+
     it "should return false if the objects are identical" do
       @provider.cron_different?.should == false
     end
@@ -298,8 +436,8 @@ CRONTAB
 
   describe "action_create" do
     before :each do
-      @provider.stub!(:write_crontab)
-      @provider.stub!(:read_crontab).and_return(nil)
+      @provider.stub(:write_crontab)
+      @provider.stub(:read_crontab).and_return(nil)
     end
 
     context "when there is no existing crontab" do
@@ -348,7 +486,7 @@ TEST=LOL
     context "when there is a crontab with no matching section" do
       before :each do
         @provider.cron_exists = false
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: something else
@@ -410,8 +548,8 @@ TEST=LOL
     context "when there is a crontab with a matching but different section" do
       before :each do
         @provider.cron_exists = true
-        @provider.stub!(:cron_different?).and_return(true)
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:cron_different?).and_return(true)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -475,11 +613,11 @@ TEST=LOL
     context "when there is a crontab with a matching section with no crontab line in it" do
       before :each do
         @provider.cron_exists = true
-        @provider.stub!(:cron_different?).and_return(true)
+        @provider.stub(:cron_different?).and_return(true)
       end
 
       it "should add the crontab to the entry" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -494,7 +632,7 @@ TEST=LOL
       end
 
       it "should not blat any following entries" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -519,7 +657,7 @@ TEST=LOL
       end
 
       it "should handle env vars with no crontab" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -559,8 +697,8 @@ HOME=/home/foo
     context "when there is a crontab with a matching and identical section" do
       before :each do
         @provider.cron_exists = true
-        @provider.stub!(:cron_different?).and_return(false)
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:cron_different?).and_return(false)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -590,8 +728,8 @@ CRONTAB
 
   describe "action_delete" do
     before :each do
-      @provider.stub!(:write_crontab)
-      @provider.stub!(:read_crontab).and_return(nil)
+      @provider.stub(:write_crontab)
+      @provider.stub(:read_crontab).and_return(nil)
     end
 
     context "when the user's crontab has no matching section" do
@@ -614,7 +752,7 @@ CRONTAB
     context "when the user has a crontab with a matching section" do
       before :each do
         @provider.cron_exists = true
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -639,7 +777,7 @@ CRONTAB
       end
 
       it "should remove any env vars with the entry" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -679,7 +817,7 @@ FOO=test
       end
 
       it "should remove the section" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -692,7 +830,7 @@ FOO=test
       end
 
       it "should not blat following sections" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -715,7 +853,7 @@ FOO=test
       end
 
       it "should remove any envvars with the section" do
-        @provider.stub!(:read_crontab).and_return(<<-CRONTAB)
+        @provider.stub(:read_crontab).and_return(<<-CRONTAB)
 0 2 * * * /some/other/command
 
 # Chef Name: cronhole some stuff
@@ -742,7 +880,7 @@ MAILTO=foo@example.com
 
   describe "read_crontab" do
     before :each do
-      @status = mock("Status", :exitstatus => 0)
+      @status = double("Status", :exitstatus => 0)
       @stdout = StringIO.new(<<-CRONTAB)
 0 2 * * * /some/other/command
 
@@ -751,7 +889,7 @@ MAILTO=foo@example.com
 
 # Another comment
       CRONTAB
-      @provider.stub!(:popen4).and_yield(1234, StringIO.new, @stdout, StringIO.new).and_return(@status)
+      @provider.stub(:popen4).and_yield(1234, StringIO.new, @stdout, StringIO.new).and_return(@status)
     end
 
     it "should call crontab -l with the user" do
@@ -772,14 +910,14 @@ MAILTO=foo@example.com
     end
 
     it "should return nil if the user has no crontab" do
-      status = mock("Status", :exitstatus => 1)
-      @provider.stub!(:popen4).and_return(status)
+      status = double("Status", :exitstatus => 1)
+      @provider.stub(:popen4).and_return(status)
       @provider.send(:read_crontab).should == nil
     end
 
     it "should raise an exception if another error occurs" do
-      status = mock("Status", :exitstatus => 2)
-      @provider.stub!(:popen4).and_return(status)
+      status = double("Status", :exitstatus => 2)
+      @provider.stub(:popen4).and_return(status)
       lambda do
         @provider.send(:read_crontab)
       end.should raise_error(Chef::Exceptions::Cron, "Error determining state of #{@new_resource.name}, exit: 2")
@@ -788,9 +926,9 @@ MAILTO=foo@example.com
 
   describe "write_crontab" do
     before :each do
-      @status = mock("Status", :exitstatus => 0)
+      @status = double("Status", :exitstatus => 0)
       @stdin = StringIO.new
-      @provider.stub!(:popen4).and_yield(1234, @stdin, StringIO.new, StringIO.new).and_return(@status)
+      @provider.stub(:popen4).and_yield(1234, @stdin, StringIO.new, StringIO.new).and_return(@status)
     end
 
     it "should call crontab for the user" do
@@ -804,7 +942,7 @@ MAILTO=foo@example.com
     end
 
     it "should raise an exception if the command returns non-zero" do
-      @status.stub!(:exitstatus).and_return(1)
+      @status.stub(:exitstatus).and_return(1)
       lambda do
         @provider.send(:write_crontab, "Foo")
       end.should raise_error(Chef::Exceptions::Cron, "Error updating state of #{@new_resource.name}, exit: 1")
@@ -816,8 +954,8 @@ MAILTO=foo@example.com
           raise Errno::EPIPE, "Test"
         end
       end
-      @status.stub!(:exitstatus).and_return(1)
-      @provider.stub!(:popen4).and_yield(1234, WriteErrPipe.new, StringIO.new, StringIO.new).and_return(@status)
+      @status.stub(:exitstatus).and_return(1)
+      @provider.stub(:popen4).and_yield(1234, WriteErrPipe.new, StringIO.new, StringIO.new).and_return(@status)
 
       Chef::Log.should_receive(:debug).with("Broken pipe - Test")
 
@@ -827,4 +965,46 @@ MAILTO=foo@example.com
     end
 
   end
+
+  describe "weekday_in_crontab" do
+    context "when weekday is symbol" do
+      it "should return weekday in crontab format" do
+        @new_resource.weekday :wednesday
+        @provider.send(:weekday_in_crontab).should eq("3")
+      end
+
+      it "should raise an error with an unknown weekday" do
+        expect { @new_resource.weekday :caturday }.to raise_error(RangeError)
+      end
+    end
+
+    context "when weekday is a number in a string" do
+      it "should return the string" do
+        @new_resource.weekday "3"
+        @provider.send(:weekday_in_crontab).should eq("3")
+      end
+
+      it "should raise an error with an out of range number" do
+        expect { @new_resource.weekday "-1" }.to raise_error(RangeError)
+      end
+    end
+
+    context "when weekday is string with the name of the week" do
+      it "should return the string" do
+        @new_resource.weekday "mon"
+        @provider.send(:weekday_in_crontab).should eq("mon")
+      end
+    end
+
+    context "when weekday is an integer" do
+      it "should return the integer" do
+        @new_resource.weekday 1
+        @provider.send(:weekday_in_crontab).should eq("1")
+      end
+
+      it "should raise an error with an out of range integer" do
+        expect { @new_resource.weekday 45 }.to raise_error(RangeError)
+      end
+    end
+  end
 end
