@@ -22,15 +22,15 @@ describe Chef::Provider::Deploy::Timestamped do
 
   before do
     @release_time = Time.utc( 2004, 8, 15, 16, 23, 42)
-    Time.stub!(:now).and_return(@release_time)
+    Time.stub(:now).and_return(@release_time)
     @expected_release_dir = "/my/deploy/dir/releases/20040815162342"
     @resource = Chef::Resource::Deploy.new("/my/deploy/dir")
     @node = Chef::Node.new
     @events = Chef::EventDispatch::Dispatcher.new
     @run_context = Chef::RunContext.new(@node, {}, @events)
     @timestamped_deploy = Chef::Provider::Deploy::Timestamped.new(@resource, @run_context)
-    @runner = mock("runnah")
-    Chef::Runner.stub!(:new).and_return(@runner)
+    @runner = double("runnah")
+    Chef::Runner.stub(:new).and_return(@runner)
   end
 
   it "gives a timestamp for release_slug" do
