@@ -35,21 +35,21 @@ describe Chef::ResourceReporter do
   before do
     @node = Chef::Node.new
     @node.name("spitfire")
-    @rest_client = mock("Chef::REST (mock)")
-    @rest_client.stub!(:post_rest).and_return(true)
+    @rest_client = double("Chef::REST (mock)")
+    @rest_client.stub(:post_rest).and_return(true)
     @resource_reporter = Chef::ResourceReporter.new(@rest_client)
-    @run_id = @resource_reporter.run_id
     @new_resource      = Chef::Resource::File.new("/tmp/a-file.txt")
     @new_resource.cookbook_name = "monkey"
-    @cookbook_version = mock("Cookbook::Version", :version => "1.2.3")
-    @new_resource.stub!(:cookbook_version).and_return(@cookbook_version)
+    @cookbook_version = double("Cookbook::Version", :version => "1.2.3")
+    @new_resource.stub(:cookbook_version).and_return(@cookbook_version)
     @current_resource  = Chef::Resource::File.new("/tmp/a-file.txt")
     @start_time = Time.new
     @end_time = Time.new + 20
     @events = Chef::EventDispatch::Dispatcher.new
     @run_context = Chef::RunContext.new(@node, {}, @events)
     @run_status = Chef::RunStatus.new(@node, @events)
-    Time.stub!(:now).and_return(@start_time, @end_time)
+    @run_id = @run_status.run_id
+    Time.stub(:now).and_return(@start_time, @end_time)
   end
 
   context "when first created" do
@@ -87,9 +87,9 @@ describe Chef::ResourceReporter do
 
   context "when chef fails" do
     before do
-      @rest_client.stub!(:create_url).and_return("reports/nodes/spitfire/runs/#{@run_id}");
-      @rest_client.stub!(:raw_http_request).and_return({"result"=>"ok"});
-      @rest_client.stub!(:post_rest).and_return({"uri"=>"https://example.com/reports/nodes/spitfire/runs/#{@run_id}"});
+      @rest_client.stub(:create_url).and_return("reports/nodes/spitfire/runs/#{@run_id}");
+      @rest_client.stub(:raw_http_request).and_return({"result"=>"ok"});
+      @rest_client.stub(:post_rest).and_return({"uri"=>"https://example.com/reports/nodes/spitfire/runs/#{@run_id}"});
 
     end
 
@@ -255,13 +255,68 @@ describe Chef::ResourceReporter do
   describe "when generating a report for the server" do
 
     before do
-      @rest_client.stub!(:create_url).and_return("reports/nodes/spitfire/runs/#{@run_id}");
-      @rest_client.stub!(:raw_http_request).and_return({"result"=>"ok"});
-      @rest_client.stub!(:post_rest).and_return({"uri"=>"https://example.com/reports/nodes/spitfire/runs/#{@run_id}"});
+      @rest_client.stub(:create_url).and_return("reports/nodes/spitfire/runs/#{@run_id}");
+      @rest_client.stub(:raw_http_request).and_return({"result"=>"ok"});
+      @rest_client.stub(:post_rest).and_return({"uri"=>"https://example.com/reports/nodes/spitfire/runs/#{@run_id}"});
 
       @resource_reporter.run_started(@run_status)
     end
 
+    context "when the new_resource does not have a string for name and identity" do
+      context "the new_resource name and id are nil" do
+        before do
+          @bad_resource = Chef::Resource::File.new("/tmp/nameless_file.txt")
+          @bad_resource.stub(:name).and_return(nil)
+          @bad_resource.stub(:identity).and_return(nil)
+          @resource_reporter.resource_action_start(@bad_resource, :create)
+          @resource_reporter.resource_current_state_loaded(@bad_resource, :create, @current_resource)
+          @resource_reporter.resource_updated(@bad_resource, :create)
+          @resource_reporter.resource_completed(@bad_resource)
+          @run_status.stop_clock
+          @report = @resource_reporter.prepare_run_data
+          @first_update_report = @report["resources"].first
+        end
+
+        it "resource_name in prepared_run_data is a string" do
+          @first_update_report["name"].class.should == String
+        end
+
+        it "resource_id in prepared_run_data is a string" do
+          @first_update_report["id"].class.should == String
+        end
+      end
+
+      context "the new_resource name and id are hashes" do
+        before do
+          @bad_resource = Chef::Resource::File.new("/tmp/filename_as_hash.txt")
+          @bad_resource.stub(:name).and_return({:foo=>:bar})
+          @bad_resource.stub(:identity).and_return({:foo=>:bar})
+          @resource_reporter.resource_action_start(@bad_resource, :create)
+          @resource_reporter.resource_current_state_loaded(@bad_resource, :create, @current_resource)
+          @resource_reporter.resource_updated(@bad_resource, :create)
+          @resource_reporter.resource_completed(@bad_resource)
+          @run_status.stop_clock
+          @report = @resource_reporter.prepare_run_data
+          @first_update_report = @report["resources"].first
+        end
+        # Ruby 1.8.7 flattens out hash to string using join instead of inspect, resulting in
+        # irb(main):001:0> {:foo => :bar}.to_s
+        # => "foobar"
+        # instead of the expected
+        # irb(main):001:0> {:foo => :bar}.to_s
+        # => "{:foo=>:bar}"
+        # Hence checking for the class instead of the actual value.
+        it "resource_name in prepared_run_data is a string" do
+          @first_update_report["name"].class.should == String
+        end
+
+        it "resource_id in prepared_run_data is a string" do
+          @first_update_report["id"].class.should == String
+        end
+      end
+    end
+
+
     context "for a successful client run" do
       before do
         # TODO: add inputs to generate expected output.
@@ -381,10 +436,10 @@ describe Chef::ResourceReporter do
         @backtrace = ["foo.rb:1 in `foo!'","bar.rb:2 in `bar!","'baz.rb:3 in `baz!'"]
         @node = Chef::Node.new
         @node.name("spitfire")
-        @exception = mock("ArgumentError")
-        @exception.stub!(:inspect).and_return("Net::HTTPServerException")
-        @exception.stub!(:message).and_return("Object not found")
-        @exception.stub!(:backtrace).and_return(@backtrace)
+        @exception = double("ArgumentError")
+        @exception.stub(:inspect).and_return("Net::HTTPServerException")
+        @exception.stub(:message).and_return("Object not found")
+        @exception.stub(:backtrace).and_return(@backtrace)
         @resource_reporter.run_list_expand_failed(@node, @exception)
         @resource_reporter.run_failed(@exception)
         @report = @resource_reporter.prepare_run_data
@@ -602,7 +657,7 @@ describe Chef::ResourceReporter do
         @resource_reporter.resource_current_state_loaded(@new_resource, :create, @current_resource)
         @resource_reporter.resource_updated(@new_resource, :create)
 
-        @resource_reporter.stub!(:end_time).and_return(@end_time)
+        @resource_reporter.stub(:end_time).and_return(@end_time)
         @expected_data = @resource_reporter.prepare_run_data
 
         post_url = "https://chef_server/example_url"
